--
-- Multiplayer Event Script
--
-- M@D Author:  Heady
-- M@D date: 22.11.2010
--
-- > Copyright (C) Heady - www.planet-ls.de < --
--

MPEvent = {};
MPEvent_mt = Class(MPEvent, Event);

InitEventClass(MPEvent, "MPEvent");

function MPEvent:emptyNew()
    local self = Event:new(MPEvent_mt);
    self.className="MPEvent";
    return self;
end;

function MPEvent:new(object)
    local self = MPEvent:emptyNew()
    self.object = object;
    return self;
end;

function MPEvent:readStream(streamId, connection)
	local id = streamReadInt32(streamId);
    self.object = networkGetObject(id);
    self.object.siloState = streamReadInt32(streamId);
    self.object.compScale = streamReadInt32(streamId);
    self.object.isTipTrigger = streamReadBool(streamId);
    self.object.setTipTrigger = streamReadBool(streamId);
	
	if connection:getIsServer() then
		self.object.silo.maxFillLevel = streamReadInt32(streamId);
	end;
	self.object:updateState(self.object.siloState);
	
	if not connection:getIsServer() then
		g_server:broadcastEvent(MPEvent:new(self.object), nil, connection, self.object);
	end;
end;

function MPEvent:writeStream(streamId, connection)
    streamWriteInt32(streamId, networkGetObjectId(self.object));
    streamWriteInt32(streamId, self.object.siloState);
    streamWriteInt32(streamId, self.object.compScale);
    streamWriteBool(streamId, self.object.isTipTrigger);
    streamWriteBool(streamId, self.object.setTipTrigger);
	if not connection:getIsServer() then
		streamWriteInt32(streamId, self.object.silo.maxFillLevel);
	end;
end;


FermentMPEvent = {};
FermentMPEvent_mt = Class(FermentMPEvent, Event);

InitEventClass(FermentMPEvent, "FermentMPEvent");

function FermentMPEvent:emptyNew()
    local self = Event:new(FermentMPEvent_mt);
    self.className="FermentMPEvent";
    return self;
end;

function FermentMPEvent:new(object)
    local self = FermentMPEvent:emptyNew()
    self.object = object;
    return self;
end;

function FermentMPEvent:readStream(streamId, connection)
	local id = streamReadInt32(streamId);
    self.object = networkGetObject(id);
    self.object.fermentTargetTime[1] = streamReadInt32(streamId);
    self.object.fermentTargetTime[2] = streamReadInt32(streamId);
    self.object.fermented = streamReadBool(streamId);
	
	if not connection:getIsServer() then
		g_server:broadcastEvent(FermentMPEvent:new(self.object), nil, connection, self.object);
	end;
end;

function FermentMPEvent:writeStream(streamId, connection)
    streamWriteInt32(streamId, networkGetObjectId(self.object));
    streamWriteInt32(streamId, self.object.fermentTargetTime[1]);
    streamWriteInt32(streamId, self.object.fermentTargetTime[2]);
    streamWriteBool(streamId, self.object.fermented);
end;


PrintDebugMPEvent = {};
PrintDebugMPEvent_mt = Class(PrintDebugMPEvent, Event);

InitEventClass(PrintDebugMPEvent, "PrintDebugMPEvent");

function PrintDebugMPEvent:emptyNew()
    local self = Event:new(PrintDebugMPEvent_mt);
    self.className="PrintDebugMPEvent";
    return self;
end;

function PrintDebugMPEvent:new(object)
    local self = PrintDebugMPEvent:emptyNew()
    self.object = object;
    return self;
end;

function PrintDebugMPEvent:readStream(streamId, connection)
	local id = streamReadInt32(streamId);
	self.object = networkGetObject(id);
	
	if connection:getIsServer() then -- if client then
		local i = streamReadInt8(streamId);
		local v1 = streamReadInt32(streamId);
		local v2 = streamReadInt32(streamId);
		local v3 = streamReadInt32(streamId);
		local v4 = streamReadInt8(streamId);
		local v5 = streamReadBool(streamId);
		local v6 = streamReadInt32(streamId);
		local v7 = streamReadInt32(streamId);
		print("silo["..i.."].silage.fillLevel: ", v1);
		print("silo["..i.."].silo.fillLevel: ", v2);
		print("silo["..i.."].silo.maxFillLevel: ", v3);
		print("silo["..i.."].siloState: ", v4);
		print("silo["..i.."].siloIsFull: ", v5);
		print("silo["..i.."].compFillLevel: ", v6);
		print("silo["..i.."].compScale: ", v7);
	end;
	
	if not connection:getIsServer() then -- if server read then send to clients
		g_server:broadcastEvent(PrintDebugMPEvent:new(self.object), nil, connection, self.object);
	end;
end;

function PrintDebugMPEvent:writeStream(streamId, connection)
    streamWriteInt32(streamId, networkGetObjectId(self.object));
	if not connection:getIsServer() then -- if server then
		for i=1, table.getn(ModEvent.silos) do
			if self.object == ModEvent.silos[i] then
				streamWriteInt8(streamId, i);
				break;
			end;
		end;
		streamWriteInt32(streamId, self.object.silage.fillLevel);
		streamWriteInt32(streamId, self.object.silo.fillLevel);
		streamWriteInt32(streamId, self.object.silo.maxFillLevel);
		streamWriteInt8(streamId, self.object.siloState);
		streamWriteBool(streamId, self.object.siloIsFull);
		streamWriteInt32(streamId, self.object.compFillLevel);
		streamWriteInt32(streamId, self.object.compScale);	
	end;
end;
